pub fn with_runner_context<F, R>(f: F) -> Option<R>where
F: FnOnce(&RunnerContext) -> R,Expand description
Access the current runner context by reference, avoiding a clone.
pub fn with_runner_context<F, R>(f: F) -> Option<R>where
F: FnOnce(&RunnerContext) -> R,Access the current runner context by reference, avoiding a clone.