pub fn lock_err(e: impl Display) -> RustvelloErrorExpand description
Convert a mutex lock-poison error into RustvelloError::Internal.
Use this in backend implementations to avoid duplicating lock-error conversion logic.
pub fn lock_err(e: impl Display) -> RustvelloErrorConvert a mutex lock-poison error into RustvelloError::Internal.
Use this in backend implementations to avoid duplicating lock-error conversion logic.