pub struct InvocationId(/* private fields */);Expand description
Uniquely identifies a single invocation instance (UUID).
Each time a call is routed for execution, a new invocation is created. Multiple invocations can exist for the same call (retries, concurrent runs).
Implementations
Sourceimpl InvocationId
impl InvocationId
pub fn new() -> InvocationId
pub fn from_string(id: impl Into<Arc<str>>) -> InvocationId
Sourcepub fn try_from_string(id: impl Into<Arc<str>>) -> Result<InvocationId, String>
pub fn try_from_string(id: impl Into<Arc<str>>) -> Result<InvocationId, String>
Create an InvocationId from a string, validating UUID format.