pub struct TriggerDefinitionDTO {
pub trigger_id: TriggerDefinitionId,
pub task_id: TaskId,
pub condition_ids: Vec<ConditionId>,
pub logic: TriggerLogic,
pub argument_template: Option<Value>,
}Expand description
A trigger definition links conditions to a target task.
When the conditions are satisfied (according to logic), the target
task is invoked with the given argument_template.
Fields
trigger_id: TriggerDefinitionIdtask_id: TaskIdcondition_ids: Vec<ConditionId>logic: TriggerLogicargument_template: Option<Value>Optional static arguments to pass to the triggered task.
Implementations
Sourceimpl TriggerDefinitionDTO
impl TriggerDefinitionDTO
Sourcepub fn compute_trigger_id(
task_id: &TaskId,
condition_ids: &[ConditionId],
logic: TriggerLogic,
) -> TriggerDefinitionId
pub fn compute_trigger_id( task_id: &TaskId, condition_ids: &[ConditionId], logic: TriggerLogic, ) -> TriggerDefinitionId
Compute a deterministic trigger ID from (task_id + sorted conditions + logic).